<?php

namespace Bluesquare\Connect\Commands;

use Bluesquare\Connect\Connect;
use Bluesquare\Connect\ConnectException;
use Bluesquare\Connect\Traits\HasConnectTokens;
use Illuminate\Console\Command;

class Sync extends Command
{
    protected $signature = 'connect:sync';

    protected $description = 'Sync Bluesquare Connect users';

    public function handle(Connect $connect)
    {
        $this->call('connect:refresh');

        $class = config('bconnect.model');

        $has_fields = in_array(HasConnectTokens::class, class_uses($class));

        if (! $has_fields) {
            throw new ConnectException("$class does not implement HasConnectTokens");
        }

        $class::query()->chunks(10, function ($models) use ($connect) {
            $models->each(function ($model) use ($connect) {
                try {
                    if (! empty($model->connect_access_token)) {
                        $data = $connect->getUserData($model->connect_access_token);
                        $connect->updateUserData($model, $data);
                        $model->save();
                    }
                }
                catch (\Exception $exception) {
                    $this->warn("Failed to sync model data", $model->toArray());
                }
            });
        });

        $this->info("Models synced");

        return 0;
    }
}
